@@ -326,8 +326,8 @@ data StmtBlockContent
 -- * Simple source import
 --
 -- @
--- # stmtImportSource is "json" 
--- # stmtImportFromSource is Nothing 
+-- # stmtImportSource is (ImportSource (ImportThirdPartyContent "json")) <--- because json is /not/ an existing dir in the repo
+-- # stmtImportSpecific is Nothing 
 -- # stmtImportAlias is Nothing
 -- import json
 -- @
@@ -335,8 +335,8 @@ data StmtBlockContent
 -- * Specifying a specific name from source
 --
 -- @
--- # stmtImportSource is "urllib.parse"
--- # stmtImportFromSource is Just "urljoin"
+-- # stmtImportSource is (ImportSource (ImportThirdPartyContent "urllib.parse")) <--- because urllib/parse is /not/ an existing dir in the repo
+-- # stmtImportSpecific is Just (ImportSpecific "urljoin")
 -- # stmtImportAlias is Nothing
 -- from urllib.parse import urljoin
 -- @
@@ -344,9 +344,9 @@ data StmtBlockContent
 -- * Specifying an alias for a source import
 --
 -- @
--- # stmtImportSource is "networkx"
+-- # stmtImportSource is (ImportSource (ImportThirdPartyContent "networkx")) <--- because networkx is /not/ an existing dir in the repo
 -- # stmtImportFromSource is Nothing
--- # stmtImportAlias is Just "nx"
+-- # stmtImportAlias is Just (ImportAlias "nx")
 -- import networkx as nx
 -- @
 --
@@ -354,8 +354,8 @@ data StmtImportContent
    = StmtImportContent
      {
          stmtImportSource :: ImportSource,
-         stmtImportFromSource :: Maybe String,
-         stmtImportAlias :: Maybe String,
+         stmtImportSpecific :: Maybe ImportSpecific,
+         stmtImportAlias :: Maybe ImportAlias,
          stmtImportLocation :: Location
      }
      deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
@@ -368,8 +368,17 @@ data ImportSource
 -- | Filename or directory
 newtype ImportLocalContent = ImportLocalContent FilePath deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
 
+-- |
+-- Names that do not exist as directories in the repo
+-- are classified by default as being "third party"
 newtype ImportThirdPartyContent = ImportThirdPartyContent String deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
 
+-- | See `StmtImportContent`
+newtype ImportSpecific = ImportSpecific String deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
+
+-- | See `StmtImportContent`
+newtype ImportAlias = ImportAlias String deriving ( Show, Eq, Ord, Generic, ToJSON, FromJSON )
+
 data StmtContinueContent
    = StmtContinueContent
      {
